@@ -22,6 +22,7 @@ Usage:
     zapgpt --list-prompt
     zapgpt --config
     zapgpt --show-prompt coding
+    zapgpt -xai "What is capital of France?"
 
 Configuration:
     Configuration and prompts are stored in ~/.config/zapgpt/
@@ -53,11 +54,11 @@ try:
         VERSION = tomli.load(f)["project"]["version"]
 except (ImportError, FileNotFoundError, KeyError):
     # Fallback version if pyproject.toml is not available
-    VERSION = "3.4.0"
+    VERSION = "3.4.14"
 from argparse import ArgumentParser, ArgumentTypeError  # For CLI parsing
 from pathlib import Path  # For path manipulations
 from textwrap import dedent  # For help/epilog formatting
-from typing import Union  # For type hints
+from typing import Optional, Union  # For type hints
 
 # ===============================
 # Third-Party Imports
@@ -645,10 +646,10 @@ class BaseLLMClient:
         self,
         model: str,
         system_prompt: str = "",
-        max_tokens: int = 1000,
         temperature: float = 0.7,
         output: str = "",
-        file: str = None,
+        file: Optional[str] = None,
+        max_tokens: Optional[int] = None,
     ):
         """
         Initialize a BaseLLMClient instance.
@@ -666,7 +667,7 @@ class BaseLLMClient:
         )
         self.model = model
         self.system_prompt = system_prompt
-        self.max_tokens = max_tokens
+        self.max_tokens = max_tokens if max_tokens else 0
         self.temperature = temperature
         self.chat_history = []
         self.current_script_path = str(current_script_path)
@@ -721,7 +722,7 @@ class BaseLLMClient:
         Record a model usage event to the database.
         """
         logger.info(
-            f"Recording usage for model={model}, provider={provider}, tokens={prompt_tokens + completion_tokens}, cost={cost}"
+            f"Recording usage for model={model}, provider={provider}, tokens={prompt_tokens + completion_tokens}, calculated cost={cost}"
         )
         conn = sqlite3.connect(DB_FILE)
         logger.debug(f"Opened {DB_FILE=}")
@@ -834,13 +835,21 @@ class BaseLLMClient:
         self.prompt_tokens = prompt_tokens
         # max_total = 128000
         # max_tokens = min(4096, max_total - prompt_tokens)  # absolute safe cap
-        params = {
-            "model": self.model,
-            "messages": prompt,
-            "temperature": self.temperature,
-            "max_tokens": self.max_tokens,
-            "top_p": 1.0,
-        }
+        if self.max_tokens:
+            params = {
+                "model": self.model,
+                "messages": prompt,
+                "temperature": self.temperature,
+                "max_tokens": self.max_tokens,
+                "top_p": 1.0,
+            }
+        else:
+            params = {
+                "model": self.model,
+                "messages": prompt,
+                "temperature": self.temperature,
+                "top_p": 1.0,
+            }
         logger.debug(f"Making request with {params=}")
         response = self.client.chat.completions.create(**params)
         logger.debug(f"{response=}")
@@ -1160,16 +1169,24 @@ class OpenAIClient(BaseLLMClient):
         temperature: int = 0.7,
         system_prompt: str = None,
         output: str = "",
-        max_tokens: int = 4096,
+        max_tokens: Optional[int] = None,
         **kwargs,
     ):
-        super().__init__(
-            model=model,
-            system_prompt=system_prompt,
-            temperature=temperature,
-            file=file,
-            max_tokens=max_tokens,
-        )
+        if max_tokens:
+            super().__init__(
+                model=model,
+                system_prompt=system_prompt,
+                temperature=temperature,
+                file=file,
+                max_tokens=max_tokens,
+            )
+        else:
+            super().__init__(
+                model=model,
+                system_prompt=system_prompt,
+                temperature=temperature,
+                file=file,
+            )
         self.api_key = api_key
         # self.system_prompt = system_prompt
         # logger.debug(f"system prompt {self.system_prompt=}")
@@ -1208,12 +1225,19 @@ class OpenAIClient(BaseLLMClient):
             dict: The payload for the OpenAI API request.
         """
         messages = self.create_prompt(prompt)
-        return {
-            "model": self.model,
-            "messages": messages,
-            "max_tokens": self.max_tokens,
-            "temperature": self.temperature,
-        }
+        if self.max_tokens:
+            return {
+                "model": self.model,
+                "messages": messages,
+                "max_tokens": self.max_tokens,
+                "temperature": self.temperature,
+            }
+        else:
+            return {
+                "model": self.model,
+                "messages": messages,
+                "temperature": self.temperature,
+            }
 
     def get_endpoint(self) -> str:
         """
@@ -1613,13 +1637,22 @@ class GithubClient(BaseLLMClient):
         self.prompt_tokens = prompt_tokens
         # max_total = 128000
         # max_tokens = min(4096, max_total - prompt_tokens)  # absolute safe cap
-        params = {
-            "model": self.model,
-            "messages": prompt,
-            "temperature": self.temperature,
-            "max_tokens": self.max_tokens,
-            "top_p": 1.0,
-        }
+        #
+        if self.max_tokens:
+            params = {
+                "model": self.model,
+                "messages": prompt,
+                "temperature": self.temperature,
+                "max_tokens": self.max_tokens,
+                "top_p": 1.0,
+            }
+        else:
+            params = {
+                "model": self.model,
+                "messages": prompt,
+                "temperature": self.temperature,
+                "top_p": 1.0,
+            }
         logger.debug(f"Making request with {params=} using requests")
         # response = self.client.chat.completions.create(**params)
         response = requests.post(self.get_endpoint(), headers=self.headers, json=params)
@@ -1779,8 +1812,8 @@ def query_llm(
     system_prompt: str = None,
     use_prompt: str = None,
     temperature: float = 0.3,
-    max_tokens: int = 4096,
     quiet: bool = True,
+    max_tokens: Optional[int] = None,
 ) -> str:
     """
     Programmatic API to query LLM providers from Python scripts.
@@ -1863,13 +1896,21 @@ def query_llm(
 
     # Create client
     client_class = provider_map[provider]
-    llm_client = client_class(
-        model=final_model,
-        api_key=api_key,
-        system_prompt=final_system_prompt,
-        temperature=temperature,
-        max_tokens=max_tokens,
-    )
+    if max_tokens:
+        llm_client = client_class(
+            model=final_model,
+            api_key=api_key,
+            system_prompt=final_system_prompt,
+            temperature=temperature,
+            max_tokens=max_tokens,
+        )
+    else:
+        llm_client = client_class(
+            model=final_model,
+            api_key=api_key,
+            system_prompt=final_system_prompt,
+            temperature=temperature,
+        )
 
     # Send request and return response
     try:
@@ -1951,7 +1992,6 @@ def main():
         "-m",
         "--model",
         type=str,
-        default="openai/gpt-4.1",
         help="Specify the model to use (default: openai/gpt-4o-mini). Available models can be listed using --list-models.",
     )
     parser.add_argument(
@@ -2002,7 +2042,6 @@ def main():
         "-te",
         "--temp",
         type=float,
-        default=0.3,
         help="Set the temperature for responses (0-1.0). Default is 0.3.",
     )
     parser.add_argument(
@@ -2035,14 +2074,13 @@ def main():
         "-p",
         "--provider",
         choices=provider_map.keys(),
-        default="github",
         help="Select LLM provider",
     )
     parser.add_argument(
         "-mt",
         "--max-tokens",
         type=int,
-        default=4096,
+        # default=4096,
         help="Use low cost LLM for OpenRouter",
     )
     parser.add_argument(
@@ -2066,11 +2104,13 @@ def main():
     )
     parser.add_argument("-o", "--output", default=None, help="The output file to use.")
     parser.add_argument(
+        "-cf",
         "--config",
         action="store_true",
         help="Show configuration directory information.",
     )
     parser.add_argument(
+        "-sp",
         "--show-prompt",
         type=str,
         help="Show the complete prompt that would be sent to LLM for the given prompt name.",
@@ -2085,6 +2125,51 @@ def main():
 
     args = parser.parse_args()
 
+    if os.path.exists(CONFIG_DIR + "/config.json"):
+        with open(CONFIG_DIR + "/config.json") as file:
+            default_values = json.load(file)
+            if "temp" in default_values:
+                temp = default_values["temp"]
+            else:
+                if args.temp:
+                    temp = args.temp
+                else:
+                    temp = 0.3
+            if "model" in default_values:
+                model = default_values["model"]
+            else:
+                if args.model:
+                    model = args.model
+                else:
+                    model = "openai/gpt-4.1"
+
+            if args.provider:
+                provider = args.provider
+            else:
+                if "provider" in default_values:
+                    provider = default_values["provider"]
+                else:
+                    provider = "openrouter"
+    else:
+        if args.temp:
+            temp = args.temp
+        else:
+            temp = 0.3
+        if args.model:
+            model = args.model
+        else:
+            model = "openai/gpt-4.1"
+
+        if args.provider:
+            provider = args.provider
+        else:
+            provider = "openrouter"
+        logger.info(
+            "No config file {CONFIG_DIR+'/config.json'} found, you can create a json with model, provider and temp for default values."
+        )
+
+    logger.warning(f"{temp=}, {model=}, {provider=}")
+
     # Handle quiet mode FIRST - suppress all output except LLM response
     if args.quiet:
         logger.setLevel(logging.CRITICAL)  # Only show critical errors
@@ -2103,12 +2188,11 @@ def main():
         logger.info("Displayed all available prompts.")
         return
 
+    mt = args.max_tokens if args.max_tokens else 0
     logger.debug(
-        f"Parsed arguments: model={args.model}, provider={args.provider}, max_tokens={args.max_tokens}"
+        f"Parsed arguments: model={model}, provider={provider}, max_tokens={mt}"
     )
 
-    model = args.model
-
     # Print zapgpt logo/banner (user-facing, not logged) - only if not quiet
     if not args.quiet:
         console.print(
@@ -2134,6 +2218,7 @@ def main():
 [bold blue]╔══════════════════════════════════════════════════╗
 ║ ⚡ [bold yellow]Zap[/bold yellow][bold white]GPT[/bold white] [dim]v{VERSION}[/dim] 🚀✨ Multi-provider AI automation 🛡️ ║
 ╚══════════════════════════════════════════════════╝[/bold blue]
+[Github](https://github.com/raj77in/zapgpt), Author: Amit Agarwal
             """,
             justify="center",
         )
@@ -2171,13 +2256,13 @@ def main():
                     logger.debug(f"Combined 'common_base' with '{prompt_name}' prompt")
 
             # User-provided model takes precedence over prompt's model
-            if args.model != "openai/gpt-4.1":  # User explicitly provided a model
-                model = args.model
+            if model != "openai/gpt-4.1":  # User explicitly provided a model
+                model = model
                 logger.info(
                     f"Using user-specified model '{model}' (overriding prompt default)"
                 )
             else:
-                model = prompt_data.get("model", args.model)
+                model = prompt_data.get("model", model)
                 logger.debug(f"Using model from prompt '{prompt_name}': '{model}'")
 
             if args.explain_AI:
@@ -2185,9 +2270,9 @@ def main():
         else:
             logger.error(f"Prompt '{prompt_name}' not found in prompts directory.")
             system_prompt = ""
-            model = args.model
+            model = model
     else:
-        model = args.model
+        model = model
 
     # Prepare assistant_input if present
     assistant_input = None
@@ -2202,20 +2287,20 @@ def main():
         return
 
     if args.show_prompt:
-        show_complete_prompt(args.show_prompt, args.model)
+        show_complete_prompt(args.show_prompt, model)
         return
 
     # Now handle commands that need API access
-    client_class = provider_map[args.provider]
+    client_class = provider_map[provider]
 
     # Get the correct API key for the selected provider
-    required_env_var = provider_env_vars.get(args.provider)
+    required_env_var = provider_env_vars.get(provider)
     api_key = None
     if required_env_var:
         api_key = os.getenv(required_env_var)
-        if not api_key and args.provider != "local":
+        if not api_key and provider != "local":
             logger.error(f"Missing required environment variable: {required_env_var}")
-            output.error(f"Missing API key for {args.provider}")
+            output.error(f"Missing API key for {provider}")
             output.warning(f"Please set the environment variable: {required_env_var}")
             sys.exit(1)
 
@@ -2228,7 +2313,7 @@ def main():
         model=model,
         api_key=api_key,
         system_prompt=system_prompt,
-        temperature=args.temp,
+        temperature=temp,
         file=args.file,
         output=args.output,
         max_tokens=args.max_tokens,
@@ -2236,7 +2321,7 @@ def main():
     )
 
     if args.image_prompt:
-        if args.provider != "openai":
+        if provider != "openai":
             output.error("Only OpenAI is supported for Image generation")
             return False
         llm_client.generate_image(args.image_prompt, args.image_size)
